<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.7.5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation>Um cliente rico em funções para YouTube, suportando navegação, reprodução e download de vídeos, além de gerenciamento de contas. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Nova Conta</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Editar Conta</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Erro na base de dados. Não foi possível guardar a conta.</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="95"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="108"/>
        <source>Default?</source>
        <translation>Padrão?</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>Contas YouTube</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Adicionar Comentário</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Partilhar através </translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Mensagem</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Adicionar à Lista</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <location filename="../ArchiveListView.qml" line="33"/>
        <source>Deleted from archive</source>
        <translation>Excluído dos arquivos</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="36"/>
        <location filename="../ArchiveListView.qml" line="53"/>
        <source>Unable to delete from archive</source>
        <translation>Não foi possível excluir dos arquivos</translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="50"/>
        <source>Loading...</source>
        <translation>A Carregar...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Mudar de Utilizador</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source>By </source>
        <translation>Por </translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <location filename="../CommentsDelegate.qml" line="23"/>
        <source> on </source>
        <translation> em </translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Espera!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>cuteTube ainda está a baixar arquivos. Quer mesmo sair?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../../controller.cpp" line="222"/>
        <source>Video deleted from device</source>
        <translation>Vídeo excluído do dispostivo</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="225"/>
        <source>Unable to delete video</source>
        <translation>Não foi possível excluir o vídeo</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="229"/>
        <source>Video not found</source>
        <translation>Não foi possível encontrar o vídeo</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="284"/>
        <source>Copied to clipboard</source>
        <translation>Copiado para Clipboard</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Escolher Arquivo de Vídeo</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <location filename="../HomeView.qml" line="119"/>
        <source>My Channel</source>
        <translation>O Meu Canal</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="143"/>
        <source>Most Recent</source>
        <translation>Os Mais Recentes</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="167"/>
        <source>Most Viewed</source>
        <translation>Os Mais Vistos</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="191"/>
        <source>Archive</source>
        <translation>Arquivos</translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <location filename="../MenuBar.qml" line="130"/>
        <source>Sort</source>
        <translation>Ordenar</translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <location filename="../MyAccountView.qml" line="81"/>
        <source>My Uploads</source>
        <translation>Os Meus Uploads</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="87"/>
        <source>Uploads</source>
        <translation>Uploads</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="105"/>
        <source>My Favourites</source>
        <translation>Os Meus Favoritos</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="111"/>
        <source>Favourites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="135"/>
        <source>Playlists</source>
        <translation>Listas de Reprodução</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="159"/>
        <source>Subscriptions</source>
        <translation>Subscrições</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="174"/>
        <source>Signed in as:</source>
        <translation>Logado em:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Nova Lista</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Descrição (opcional)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Privado?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Olá!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>O Meu Nome é Cutey. O meu companheiro Clippy diz-me que é a primeira vez que estás a usar cuteTube. Gostavas de adicionar uma conta YouTube?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>Vai-te embora!</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="51"/>
        <source>No active downloads</source>
        <translation>Sem downloads activos</translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="146"/>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Autorização para:</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Erro ao obter a autorização do facebook</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Coloca o código pin</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="31"/>
        <source> videos</source>
        <translation> vídeos</translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <location filename="../PlaylistVideosView.qml" line="59"/>
        <source>Video(s) deleted from playlist</source>
        <translation>Vídeo(s) excluído(s) da lista</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="80"/>
        <source>No videos found</source>
        <translation>Não foram encontrados vídeos</translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="58"/>
        <source>New playlist created</source>
        <translation>Nova lista criada</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="106"/>
        <source>No playlists found</source>
        <translation>Não foram encontradas nenhuma lista</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="30"/>
        <source>Network Proxy</source>
        <translation>Proxy da Rede</translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="44"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation>Anfitrião (ex: 192.168.100.1)</translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="51"/>
        <source>Port (e.g. 8080)</source>
        <translation>Porta (ex: 8080)</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Relevance</source>
        <translation>Relevância</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Rating</source>
        <translation>Classificação</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Views</source>
        <translation>Vistas</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="181"/>
        <source>Order by:</source>
        <translation>Ordenar por:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="195"/>
        <source>Your saved searches have been cleared</source>
        <translation>As suas pesquisas salvas foram limpas</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="198"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Erro na base de dados. Impossível eliminar as pesquisas</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="245"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="311"/>
        <source>Playback quality</source>
        <translation>Qualidade de reprodução</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="320"/>
        <source>Download quality</source>
        <translation>Qualidade de download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="286"/>
        <source>Start downloads</source>
        <translation>Iniciar downloads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="354"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="379"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="387"/>
        <source>Download location</source>
        <translation>Localização de Downloads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="396"/>
        <source>Screen orientation</source>
        <translation>Orientação do Ecrã</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="302"/>
        <source>Media player</source>
        <translation>Leitor Média</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="171"/>
        <location filename="../SettingsDialog.qml" line="371"/>
        <location filename="../SettingsDialog.qml" line="373"/>
        <source>Language</source>
        <translation>Língua</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="37"/>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>High quality</source>
        <translation>Alta Qualidade</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Most recent</source>
        <translation>Mais recente</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Most viewed</source>
        <translation>Mais vistos</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Archive</source>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Latest subscription videos</source>
        <translation>Últimas subscrições de vídeos</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>My uploads</source>
        <translation>Meus uploads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>My favourites</source>
        <translation>Meus favoritos</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="123"/>
        <location filename="../SettingsDialog.qml" line="174"/>
        <source>Network Proxy</source>
        <translation>Proxy da Rede</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="147"/>
        <location filename="../SettingsDialog.qml" line="313"/>
        <source>Playback Quality</source>
        <translation>Qualidade de Reprodução</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="150"/>
        <location filename="../SettingsDialog.qml" line="322"/>
        <source>Download Quality</source>
        <translation>Qualidade de Download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="153"/>
        <location filename="../SettingsDialog.qml" line="288"/>
        <source>Start Downloads</source>
        <translation>Iniciar Downloads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="162"/>
        <location filename="../SettingsDialog.qml" line="398"/>
        <source>Screen Orientation</source>
        <translation>Orientação do Ecrã</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="165"/>
        <location filename="../SettingsDialog.qml" line="304"/>
        <source>Media Player</source>
        <translation>Leitor Média</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="37"/>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>Mobile</source>
        <translation>Móvel</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>360p</source>
        <translation>360p</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>480p</source>
        <translation>480p</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>720p</source>
        <translation>720p</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Automatically</source>
        <translation>Automaticamente</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Manually</source>
        <translation>Manualmente</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Automatic</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Landscape</source>
        <translation>Modo Paisagem</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Portrait</source>
        <translation>Modo Retrato</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>English</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>German</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Finnish</source>
        <translation>Finlandês</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Dutch</source>
        <translation>Holandês</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Polish</source>
        <translation>Polonês</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="108"/>
        <source>Your settings have been saved</source>
        <translation>As tuas definições foram salvas</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="113"/>
        <location filename="../SettingsDialog.qml" line="156"/>
        <source>Download Path</source>
        <translation>Caminho dos Downloads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="115"/>
        <source>Download Location</source>
        <translation>Localização dos Downloads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="159"/>
        <location filename="../SettingsDialog.qml" line="338"/>
        <source>Safe Search</source>
        <translation>Pesquisa Segura</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="168"/>
        <location filename="../SettingsDialog.qml" line="362"/>
        <location filename="../SettingsDialog.qml" line="364"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="177"/>
        <location filename="../SettingsDialog.qml" line="422"/>
        <source>Widget Feed One</source>
        <translation>Widget Feed Um</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="180"/>
        <location filename="../SettingsDialog.qml" line="431"/>
        <source>Widget Feed Two</source>
        <translation>Widget Feed Dois</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="183"/>
        <location filename="../SettingsDialog.qml" line="440"/>
        <source>Widget Feed Three</source>
        <translation>Widget Feed Três</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="186"/>
        <location filename="../SettingsDialog.qml" line="449"/>
        <source>Widget Feed Four</source>
        <translation>Widget Feed Quatro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="269"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="277"/>
        <source>Network proxy</source>
        <translation>Proxy da rede</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="294"/>
        <source>Media</source>
        <translation>Média</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="328"/>
        <source>YouTube searches</source>
        <translation>Pesquisas do YouTube</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="336"/>
        <source>Safe search</source>
        <translation>Pesquisa segura</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="412"/>
        <source>Widget</source>
        <translation>Widget</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="420"/>
        <source>Feed one</source>
        <translation>Feed um</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="429"/>
        <source>Feed two</source>
        <translation>Feed dois</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="438"/>
        <source>Feed three</source>
        <translation>Feed três</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="447"/>
        <source>Feed four</source>
        <translation>Feed quatro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="278"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="347"/>
        <source>Clear saved searches</source>
        <translation>Excluir pesquisas salvas</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Erro - Resposta do servidor é:</translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="36"/>
        <source>Latest Subscriptions Videos</source>
        <translation>Últimos Vídeos Subscritos</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="45"/>
        <source>You have unsubscribed to this channel</source>
        <translation>Cancelaste a subscrição deste canal</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="104"/>
        <source>No subscriptions found</source>
        <translation>Não foram encontradas subscrições</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Automóveis</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Comedy</source>
        <translation>Humor</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <source>Education</source>
        <translation>Ensino</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <location filename="../UploadDialog.qml" line="19"/>
        <source>Entertainment</source>
        <translation>Entretenimento</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Film and Animation</source>
        <translation>Filmes e Animação</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Gaming</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Howto &amp; Style</source>
        <translation>Guias e Estilo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>News &amp; Politics</source>
        <translation>Notícias e Política</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Sem fins lucrativos e Activismo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>People &amp; Blogs</source>
        <translation>Pessoas e Blogues</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Pets &amp; Animals</source>
        <translation>Animais</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Science &amp; Technology</source>
        <translation>Ciência e Tecnologia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Sport</source>
        <translation>Desporto</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Travel &amp; Events</source>
        <translation>Viagens e Eventos</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="35"/>
        <location filename="../UploadDialog.qml" line="216"/>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="114"/>
        <source>Upload Video</source>
        <translation>Carregar Vídeo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="139"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="148"/>
        <location filename="../UploadDialog.qml" line="224"/>
        <source>None chosen</source>
        <translation>Nenhum escolhido</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="164"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="177"/>
        <source>Description (optional)</source>
        <translation>Descrição (opcional)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="189"/>
        <source>Tags (seperated by commas)</source>
        <translation>Etiquetas (separadas por vírgulas)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="202"/>
        <source>Private?</source>
        <translation>Privado?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>A iniciar o upload</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Progresso do Upload</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Nome do arquivo</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Upload em progresso</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="127"/>
        <source>Subscribers</source>
        <translation>Subscritores</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="141"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="117"/>
        <source>You have subscribed to &apos;</source>
        <translation>Você subscreveu &apos;</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="121"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>Você deixou de subscrever &apos;</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="141"/>
        <source>No videos found</source>
        <translation>Não foram encontrados vídeos</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="200"/>
        <source>Subscribers</source>
        <translation>Subscritores</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="214"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="237"/>
        <source>Unsubscribe</source>
        <translation>Anular Subscrição</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="237"/>
        <source>Subscribe</source>
        <translation>Subscrever</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Sem descrição</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="92"/>
        <source>Your comment has been added</source>
        <translation>O seu comentário foi adicionado</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="95"/>
        <source>Your rating has been added</source>
        <translation>A sua classificação foi adicionada</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="102"/>
        <source>Video shared on facebook</source>
        <translation>Vídeo partilhado no facebook</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="443"/>
        <location filename="../VideoInfoView.qml" line="467"/>
        <location filename="../VideoInfoView.qml" line="580"/>
        <source>You are not signed in to a YouTube account</source>
        <translation>Não estás logado numa conta YouTube</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="244"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="283"/>
        <source>Comments</source>
        <translation>Comentários</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="322"/>
        <source>Related</source>
        <translation>Relacionado</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="413"/>
        <location filename="../VideoInfoView.qml" line="416"/>
        <source>By </source>
        <translation>Por </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="415"/>
        <location filename="../VideoInfoView.qml" line="418"/>
        <source> on </source>
        <translation> em </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="484"/>
        <source>Views</source>
        <translation>Vistas</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="498"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="514"/>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="524"/>
        <source>No tags</source>
        <translation>Sem etiquetas</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="592"/>
        <source>No comments</source>
        <translation>Sem comentários</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="592"/>
        <source> comments</source>
        <translation> comentários</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="685"/>
        <source>No related videos</source>
        <translation>Sem vídeos relacionados</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source>By </source>
        <translation>Por </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source> on </source>
        <translation> em </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="102"/>
        <source>Views</source>
        <translation>Vistas</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <location filename="../VideoListView.qml" line="70"/>
        <source>Video(s) deleted from favourites</source>
        <translation>Vídeo(s) excluído(s) dos favoritos</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="92"/>
        <source>No videos found</source>
        <translation>Nenhum vídeo encontrado</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="40"/>
        <source>Error obtaining access token</source>
        <translation>Erro ao obter o token de acesso</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="55"/>
        <source>Authentication failed</source>
        <translation>Autenticação falhou</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="59"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>Estás logado no YouTube como &apos;</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="121"/>
        <location filename="../../../youtube.cpp" line="227"/>
        <source>Error - Server repsonse is: </source>
        <translation>Erro - Resposta do servidor é:</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="171"/>
        <location filename="../../../youtube.cpp" line="179"/>
        <source>Upload aborted</source>
        <translation>Upload abortado</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="186"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Upload interrompido. A tentar resumir...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="190"/>
        <source>Upload failed</source>
        <translation>Upload falhou</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="196"/>
        <source>Upload is completed</source>
        <translation>Upload completo</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="388"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Erro: Não foi possível obter o vídeo</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="112"/>
        <source>Video(s) added to download queue</source>
        <translation>Vídeo(s) adicionado(s) à fila de download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="115"/>
        <source>Video(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="126"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Faixa(s) de áudio adicionada(s) á fila de download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="129"/>
        <source>Audio track(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="160"/>
        <source>Video added to favourites</source>
        <translation>Vídeo adicionado aos favoritos</translation>
    </message>
    <message>
        <location filename="../main.qml" line="161"/>
        <source>Video added to playlist</source>
        <translation>Vídeo adicionado à lista</translation>
    </message>
    <message>
        <location filename="../main.qml" line="169"/>
        <source>New playlist created</source>
        <translation>Nova lista criada</translation>
    </message>
    <message>
        <location filename="../main.qml" line="219"/>
        <source>Conversion of &apos;</source>
        <translation>Conversão de &apos;</translation>
    </message>
    <message>
        <location filename="../main.qml" line="219"/>
        <source>&apos; failed</source>
        <translation>&apos; falhou</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Queued</source>
        <translation>Em espera</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Downloading</source>
        <translation>Downloading</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Converting</source>
        <translation>Conversão</translation>
    </message>
    <message>
        <location filename="../main.qml" line="416"/>
        <source>Most Recent</source>
        <translation>Mais Recente</translation>
    </message>
    <message>
        <location filename="../main.qml" line="417"/>
        <source>Most Viewed</source>
        <translation>Mais Vistos</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <location filename="../scripts/mainscripts.js" line="152"/>
        <source>My Channel</source>
        <translation>Meu Canal</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="167"/>
        <source>Archive</source>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="206"/>
        <source>My Playlists</source>
        <translation>Minhas Listas</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="216"/>
        <source>My Subscriptions</source>
        <translation>Minhas Subscrições</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="229"/>
        <source>Video Info</source>
        <translation>Info. do Vídeo</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="239"/>
        <source>Video Playback</source>
        <translation>Reprodução de Vídeo</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="252"/>
        <source>Search </source>
        <translation>Pesquisar </translation>
    </message>
</context>
</TS>
